@@ -6,22 +6,17 @@ from __future__ import absolute_import
 from kubernetes_asyncio.client.api.well_known_api import WellKnownApi
 from kubernetes_asyncio.client.api.admissionregistration_api import AdmissionregistrationApi
 from kubernetes_asyncio.client.api.admissionregistration_v1_api import AdmissionregistrationV1Api
-from kubernetes_asyncio.client.api.admissionregistration_v1beta1_api import AdmissionregistrationV1beta1Api
 from kubernetes_asyncio.client.api.apiextensions_api import ApiextensionsApi
 from kubernetes_asyncio.client.api.apiextensions_v1_api import ApiextensionsV1Api
-from kubernetes_asyncio.client.api.apiextensions_v1beta1_api import ApiextensionsV1beta1Api
 from kubernetes_asyncio.client.api.apiregistration_api import ApiregistrationApi
 from kubernetes_asyncio.client.api.apiregistration_v1_api import ApiregistrationV1Api
-from kubernetes_asyncio.client.api.apiregistration_v1beta1_api import ApiregistrationV1beta1Api
 from kubernetes_asyncio.client.api.apis_api import ApisApi
 from kubernetes_asyncio.client.api.apps_api import AppsApi
 from kubernetes_asyncio.client.api.apps_v1_api import AppsV1Api
 from kubernetes_asyncio.client.api.authentication_api import AuthenticationApi
 from kubernetes_asyncio.client.api.authentication_v1_api import AuthenticationV1Api
-from kubernetes_asyncio.client.api.authentication_v1beta1_api import AuthenticationV1beta1Api
 from kubernetes_asyncio.client.api.authorization_api import AuthorizationApi
 from kubernetes_asyncio.client.api.authorization_v1_api import AuthorizationV1Api
-from kubernetes_asyncio.client.api.authorization_v1beta1_api import AuthorizationV1beta1Api
 from kubernetes_asyncio.client.api.autoscaling_api import AutoscalingApi
 from kubernetes_asyncio.client.api.autoscaling_v1_api import AutoscalingV1Api
 from kubernetes_asyncio.client.api.autoscaling_v2beta1_api import AutoscalingV2beta1Api
@@ -31,10 +26,8 @@ from kubernetes_asyncio.client.api.batch_v1_api import BatchV1Api
 from kubernetes_asyncio.client.api.batch_v1beta1_api import BatchV1beta1Api
 from kubernetes_asyncio.client.api.certificates_api import CertificatesApi
 from kubernetes_asyncio.client.api.certificates_v1_api import CertificatesV1Api
-from kubernetes_asyncio.client.api.certificates_v1beta1_api import CertificatesV1beta1Api
 from kubernetes_asyncio.client.api.coordination_api import CoordinationApi
 from kubernetes_asyncio.client.api.coordination_v1_api import CoordinationV1Api
-from kubernetes_asyncio.client.api.coordination_v1beta1_api import CoordinationV1beta1Api
 from kubernetes_asyncio.client.api.core_api import CoreApi
 from kubernetes_asyncio.client.api.core_v1_api import CoreV1Api
 from kubernetes_asyncio.client.api.custom_objects_api import CustomObjectsApi
@@ -44,8 +37,6 @@ from kubernetes_asyncio.client.api.discovery_v1beta1_api import DiscoveryV1beta1
 from kubernetes_asyncio.client.api.events_api import EventsApi
 from kubernetes_asyncio.client.api.events_v1_api import EventsV1Api
 from kubernetes_asyncio.client.api.events_v1beta1_api import EventsV1beta1Api
-from kubernetes_asyncio.client.api.extensions_api import ExtensionsApi
-from kubernetes_asyncio.client.api.extensions_v1beta1_api import ExtensionsV1beta1Api
 from kubernetes_asyncio.client.api.flowcontrol_apiserver_api import FlowcontrolApiserverApi
 from kubernetes_asyncio.client.api.flowcontrol_apiserver_v1beta1_api import FlowcontrolApiserverV1beta1Api
 from kubernetes_asyncio.client.api.internal_apiserver_api import InternalApiserverApi
@@ -53,7 +44,6 @@ from kubernetes_asyncio.client.api.internal_apiserver_v1alpha1_api import Intern
 from kubernetes_asyncio.client.api.logs_api import LogsApi
 from kubernetes_asyncio.client.api.networking_api import NetworkingApi
 from kubernetes_asyncio.client.api.networking_v1_api import NetworkingV1Api
-from kubernetes_asyncio.client.api.networking_v1beta1_api import NetworkingV1beta1Api
 from kubernetes_asyncio.client.api.node_api import NodeApi
 from kubernetes_asyncio.client.api.node_v1_api import NodeV1Api
 from kubernetes_asyncio.client.api.node_v1alpha1_api import NodeV1alpha1Api
@@ -65,11 +55,9 @@ from kubernetes_asyncio.client.api.policy_v1beta1_api import PolicyV1beta1Api
 from kubernetes_asyncio.client.api.rbac_authorization_api import RbacAuthorizationApi
 from kubernetes_asyncio.client.api.rbac_authorization_v1_api import RbacAuthorizationV1Api
 from kubernetes_asyncio.client.api.rbac_authorization_v1alpha1_api import RbacAuthorizationV1alpha1Api
-from kubernetes_asyncio.client.api.rbac_authorization_v1beta1_api import RbacAuthorizationV1beta1Api
 from kubernetes_asyncio.client.api.scheduling_api import SchedulingApi
 from kubernetes_asyncio.client.api.scheduling_v1_api import SchedulingV1Api
 from kubernetes_asyncio.client.api.scheduling_v1alpha1_api import SchedulingV1alpha1Api
-from kubernetes_asyncio.client.api.scheduling_v1beta1_api import SchedulingV1beta1Api
 from kubernetes_asyncio.client.api.storage_api import StorageApi
 from kubernetes_asyncio.client.api.storage_v1_api import StorageV1Api
 from kubernetes_asyncio.client.api.storage_v1alpha1_api import StorageV1alpha1Api
