@@ -15,6 +15,6 @@
 from .config_exception import ConfigException
 from .incluster_config import load_incluster_config
 from .kube_config import (
-    list_kube_config_contexts, load_kube_config, new_client_from_config,
-    refresh_token,
+    list_kube_config_contexts, load_kube_config, load_kube_config_from_dict,
+    new_client_from_config, new_client_from_config_dict, refresh_token,
 )
